@@ -134,6 +134,11 @@ start_db_capturing <- function(path, redact_columns = NULL) {
     exit = dbColumnInfoTrace
   ))
 
+  quietly(trace_dbi(
+    "dbGetRowsAffected",
+    exit = dbGetRowsAffectedTrace
+  ))
+
   # TODO: for RPostgreSQL to work, we need to prevent RPostgreSQL's
   # `postgresqlCloseConnection` from calling `dbListResults` which over-writes
   # our fixture
@@ -183,7 +188,13 @@ dbConnectTrace <- quote({
 })
 
 dbSendQueryTrace <- quote({
-  if (dittodb_debug_level(1)) {
+  if (dittodb_debug_level(2)) {
+    message(
+      "The statement: \n", statement,
+      "\nwhich has been cleaned to: \n", clean_statement(statement),
+      "\nis being hased to: ", hash(statement)
+    )
+  } else if (dittodb_debug_level(1)) {
     message(
       "The statement: \n", statement,
       "\nis being hased to: ", hash(statement)
@@ -238,7 +249,7 @@ dbGetInfoConTrace <- quote({
 dbGetInfoResultTrace <- quote({
   thing <- returnValue()
   # TODO: would this be better if we traced the methods individually?
-  if (inherits(dbObj, c("MariaDBResult", "PqResult"))) {
+  if (inherits(dbObj, c("MariaDBResult", "PqResult", "SQLiteResult"))) {
     hash <- hash(dbObj@sql)
   } else if (inherits(dbObj, "OdbcResult")) {
     hash <- hash(dbObj@statement)
@@ -261,13 +272,14 @@ dbGetInfoPsqlresultTrace <- quote({
   }
 })
 
+# TODO: rationalize these so that they are the same for any list/scalar?
 dbColumnInfoTrace <- quote({
   thing <- returnValue()
   # TODO: would this be better if we traced the methods using signature?
   if (inherits(res, "PostgreSQLResult")) {
     result_info <- RPostgreSQL::postgresqlResultInfo(res)
     hash <- hash(result_info$statement)
-  } else if (inherits(res, c("MariaDBResult", "PqResult"))) {
+  } else if (inherits(res, c("MariaDBResult", "PqResult", "SQLiteResult"))) {
     hash <- hash(res@sql)
   } else if (inherits(res, "OdbcResult")) {
     hash <- hash(res@statement)
@@ -278,12 +290,30 @@ dbColumnInfoTrace <- quote({
   dput(thing, path, control = c("all", "hexNumeric"))
 })
 
+dbGetRowsAffectedTrace <- quote({
+  thing <- returnValue()
+  # TODO: would this be better if we traced the methods using signature?
+  if (inherits(res, "PostgreSQLResult")) {
+    result_info <- RPostgreSQL::postgresqlResultInfo(res)
+    hash <- hash(result_info$statement)
+  } else if (inherits(res, c("MariaDBResult", "PqResult", "SQLiteResult"))) {
+    hash <- hash(res@sql)
+  } else if (inherits(res, "OdbcResult")) {
+    hash <- hash(res@statement)
+  } else {
+    # TODO: some default?
+  }
+  path <- make_path(.dittodb_env$db_path, "dbGetRowsAffected", hash)
+  dput(thing, path, control = c("all", "hexNumeric"))
+})
+
 #' @rdname capture_requests
 #' @export
 stop_db_capturing <- function() {
   for (func in c(
     "dbSendQuery", "dbFetch", "dbConnect", "fetch", "dbListTables",
-    "dbExistsTable", "dbListFields", "dbColumnInfo", "dbGetInfo")) {
+    "dbExistsTable", "dbListFields", "dbColumnInfo", "dbGetInfo",
+    "dbGetRowsAffected")) {
     # make sure we untrace the function:
     # * from the DBI namespace
     # * from the DBI environment
